from flask import Flask, render_template, request
import os
import ssl
import certifi
from pytube import YouTube
from pytube.exceptions import RegexMatchError

app = Flask(__name__)

# Configuración para la verificación del certificado SSL
ssl._create_default_https_context = ssl.create_default_context(cafile=certifi.where())

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/download', methods=['POST'])
def download():
    url = request.form['url']
    format_option = request.form['format']
    output_path = request.form['output_path']

    if not output_path:
        return render_template('index.html', error_message="Debe ingresar una ruta de destino válida.")

    try:
        yt = YouTube(url)
        if format_option == 'mp4':
            video = yt.streams.filter(file_extension='mp4', progressive=True).first()
        elif format_option == 'mp3':
            video = yt.streams.filter(only_audio=True).first()
        else:
            return render_template('index.html', error_message="Formato de descarga no válido.")

        if not video:
            return render_template('index.html', error_message="No se encontró ningún video disponible en el formato seleccionado.")

        video.download(output_path)
        return render_template('index.html', success_message="Descarga completada.")
    except RegexMatchError:
        return render_template('index.html', error_message="El enlace de YouTube no es válido. Asegúrate de ingresar un enlace correcto.")
    except Exception as e:
        return render_template('index.html', error_message=f"Error durante la descarga: {e}")

if __name__ == "__main__":
    app.run(debug=True)
